@@ -11,6 +11,7 @@ import os
 import yaml
 import json
 from mrtutils.mrtYamlHelper import *
+from mrtutils.mrtTemplateHelper import *
 
 
 sizeDict = {
@@ -271,6 +272,44 @@ class RegField:
         
         return self.desc, message
 
+    def getRstTable(self):
+        
+        t =TemplateHelper()
+        lName =12
+        lVal =12
+        lDesc =12
+        lines = []
+
+        for val in self.vals:
+            if len(val.name) > lName:
+                lName = len(val.name) 
+
+            if len(val.formatVal()) > lVal:
+                lVal = len(reg.formatVal())
+
+            if len(val.desc) > lDesc:
+                lDesc = len(val.desc)
+        
+        lName +=2
+        lVal +=2
+        lDesc +=2
+
+        divLine = "+" + ("-"* lName) + "+" + ("-"* lVal) + "+" + ("-"* lDesc)  + "+"
+        titleLine = "|" + t.padAfter("Name", lName) + "|" + t.padAfter("Address", lVal) + "|" + t.padAfter("Description", lDesc)  + "|"
+        headLine = divLine.replace("-","=")
+
+        lines.append(divLine)
+        lines.append(titleLine)
+        lines.append(headLine)
+
+        for val in self.vals:
+            line = "|" + t.padAfter(val.name, lName) + "|" + t.padAfter(val.formatVal(), lVal) +"|" + t.padAfter(val.desc, lDesc)  + "|"
+            lines.append(line)
+            lines.append(divLine)
+
+
+        return '\n'.join(lines)
+
     def getDict(self):
         val_arr = []
         for val in self.vals:
@@ -279,8 +318,8 @@ class RegField:
         json_dict = { "mask": self.mask, "size": self.bitCount, "offset": self.offset, "desc": self.desc, "vals": val_arr}
 
         return json_dict
-        
-
+    
+    
         
 
 class DeviceReg:
@@ -384,6 +423,58 @@ class DeviceReg:
             ret = ret + (" " * spaces)
         return ret
 
+        
+
+    def getRstTable(self):
+        
+        t = TemplateHelper()
+        cols = self.size * 8 
+        bits = cols -1
+        cellWidth = 3
+        fieldBitMap = {}
+
+        if len(self.fields) == 0:
+            cellWidth = len(self.name)
+
+        for field in self.fields:
+            fieldBitMap[field.startBit] = field
+            if len(field.name) > cellWidth:
+                cellWidth = len(field.name)
+        
+        lines = ["+------------","|Bit         ", "+============", "| **Field**  ","+------------"]
+
+        for i in range(bits,-1,-1):
+            lines[0] += '+' + ("-"* cellWidth)
+            lines[1] += '|' + t.padAfter(str(i),cellWidth) 
+            lines[2] += '+' + ("="* cellWidth)
+
+            if i in fieldBitMap:
+                lines[3] += "|"+ t.padAfter(fieldBitMap[i].name, cellWidth) 
+                lines[4] += '+' + ("-"* cellWidth)
+            else: 
+                if i == bits:
+                    if len(self.fields) == 0:
+                        lines[3] += '|' + t.padAfter(self.name,cellWidth)
+                    else:
+                        lines[3] += '|' + (" "* cellWidth)
+                    lines[4] += '+' + ("-"* cellWidth)
+                else:
+                    lines[3] += ' ' + (" "* cellWidth)
+                    lines[4] += '-' + ("-"* cellWidth)
+        
+        lines[0]+="+"
+        lines[1]+="|"
+        lines[2]+="+"
+        lines[3]+="|"
+        lines[4]+="+"
+
+        return '\n'.join(lines)
+
+
+
+
+        
+
     def getDict(self):
         field_dict = {}
 
@@ -392,6 +483,8 @@ class DeviceReg:
 
         json_dict = {"name": self.name, "addr": self.addr, "type": self.type, "size": self.size * 8, "perm": self.perm.upper(), "default":self.default, "hasDefault":self.hasDefault, "desc": self.desc, "fields": field_dict}
         return json_dict
+    
+
 
 
 class Device:
@@ -624,6 +717,59 @@ class Device:
         json_dict = {"name": self.name, "regs": reg_dict, "configs": cfg_dict, "currentVals": self.defaults, "smallestReg" : self.smallestReg * 8 , "largestReg": self.largestReg * 8}
 
         return json_dict
+
+    def getRstTable(self):
+        
+        t =TemplateHelper()
+        lName =12
+        lAddr =12
+        lType =12
+        lAccess =12
+        lDef =12
+        lDesc =12
+        lines = []
+
+        for key,reg in self.regs.items():
+            if len(reg.name) > lName:
+                lName = len(reg.name) 
+
+            if len(reg.printAddr()) > lAddr:
+                lAddr = len(reg.printAddr())
+
+            if len(reg.type) > lType:
+                lType = len(reg.type)
+
+            if len(reg.perm) > lAccess:
+                lAccess = len(reg.perm)
+
+            if len(reg.formatHex(reg.default)) > lDef:
+                lDef = len(reg.formatHex(reg.default))
+
+            if len(reg.desc) > lDesc:
+                lDesc = len(reg.desc)
+        
+        lName +=2
+        lAddr +=2
+        lType +=2
+        lAccess +=2
+        lDef +=2
+        lDesc +=2
+
+        divLine = "+" + ("-"* lName) + "+" + ("-"* lAddr) + "+" + ("-"* lType)  + "+" + ("-"* lAccess) + "+" + ("-"* lDef) + "+" + ("-"* lDesc)  + "+"
+        titleLine = "|" + t.padAfter("Name", lName) + "|" + t.padAfter("Address", lAddr) + "|" + t.padAfter("Type", lType)  + "|" + t.padAfter("Access", lAccess) + "|" + t.padAfter("Default", lDef) + "|" + t.padAfter("Description", lDesc)  + "|"
+        headLine = divLine.replace("-","=")
+
+        lines.append(divLine)
+        lines.append(titleLine)
+        lines.append(headLine)
+
+        for key,reg in self.regs.items():
+            line = "|" + t.padAfter(reg.name, lName) + "|" + t.padAfter(reg.printAddr(), lAddr) + "|" + t.padAfter(reg.type, lType)  + "|" + t.padAfter(reg.perm, lAccess) + "|" + t.padAfter(reg.formatHex(reg.default), lDef) + "|" + t.padAfter(reg.desc, lDesc)  + "|"
+            lines.append(line)
+            lines.append(divLine)
+
+
+        return '\n'.join(lines)
     
     def printJSON(self):
         return json.dumps(self.getDict());
